.. _checkAwsS3:

checkS3
-------

.. automodule:: geomancy.checks.aws.s3
  :noindex:

.. card::

    Parameters
    ^^^

    ``checkAwsS3``: str
        | Check the given S3 bucket
        | *aliases*: ``CheckS3``, ``checkAWSS3``, ``checkAwsS3``,
          ``CheckAwsS3``

    ``private``: bool
        | Security check the public availability of the bucket
        | *default*: True

    .. include:: snippets/common_args.rst

    .. include:: ../snippets/common_args.rst

.. tab-set::

    .. tab-item:: Example 1 (yaml)

        The ``checkAwsS3`` check in YAML format.

        .. code-block:: yaml

            checks:
              AWS:
                TemplatesS3Bucket:
                  desc: The bucket for cloudformation templates
                  checkS3: "myproject-cfn-templates"

    .. tab-item:: Example 2 (toml)

        The ``checkAwsS3`` check in TOML format.

        .. code-block:: toml

            [checks.AWS.TemplatesS3Bucket]
            desc = "The bucket for cloudformation templates"
            checkS3 = "myproject-cfn-templates"

    .. tab-item:: Example 3 (toml)

        The ``checkAwsS3`` check in abbreviated TOML format.

        .. code-block:: toml

            [checks.AWS]
            TemplatesS3Bucket = {desc = "The bucket for cloudformation templates", checkS3 = "myproject-cfn-templates"}

.. versionadded:: 1.0.0
